summaryrefslogtreecommitdiffstats
path: root/src/detailedlistview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit89c017c3d5126cabd96acce26f538b37b48c085f (patch)
tree115673043b52ffe2e5f8b01ebcd7b886e0a1318b /src/detailedlistview.h
parent0254ebaa5e056092461fd585b6851d15faa43035 (diff)
downloadtellico-89c017c3d5126cabd96acce26f538b37b48c085f.tar.gz
tellico-89c017c3d5126cabd96acce26f538b37b48c085f.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/detailedlistview.h')
-rw-r--r--src/detailedlistview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/detailedlistview.h b/src/detailedlistview.h
index c0efa9d..a5f718d 100644
--- a/src/detailedlistview.h
+++ b/src/detailedlistview.h
@@ -41,10 +41,10 @@ public:
/**
* The constructor initializes the popup menu, but no columns are inserted.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- DetailedListView(TQWidget* tqparent, const char* name=0);
+ DetailedListView(TQWidget* parent, const char* name=0);
~DetailedListView();
/**
@@ -41,10 +41,10 @@ public:
* The constructor initializes the popup menu, but no columns are inserted.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/